==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Stories_Archive/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Druckbare Version");
define("_FRIEND","Diesen Artikel an einen Freund senden");



define("_ARTICLES","Artikel");
define("_USCORE","Wertung");
define("_DATE","Datum");
define("_JANUARY","Januar");
define("_FEBRUARY","Februar");
define("_MARCH","M&auml;rz");
define("_APRIL","April");
define("_MAY","Mai");
define("_JUNE","Juni");
define("_JULY","Juli");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","Oktober");
define("_NOVEMBER","November");
define("_DECEMBER","Dezember");
define("_SELECTMONTH2VIEW","W&Auml;hle einen Monat der angezeigt werden soll:");
define("_SHOWALLSTORIES","Zeige ALLE Stories");
define("_STORIESARCHIVE","Stories Archiv");
define("_ACTIONS","Aktionen");
define("_ARCHIVESINDEX","Stories Archiv Index");
define("_ALLSTORIESARCH","Alle Stories");
define("_NEXTPAGE","N&auml;chste Seite");
define("_PREVIOUSPAGE","Vorhergehende Seite");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Stories_Archive/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Druckbare Version");
define("_FRIEND","Diesen Artikel an einen Freund senden");
define("_ARTICLES","Artikel");
define("_USCORE","Wertung");
define("_DATE","Datum");
define("_SELECTMONTH2VIEW","W&Auml;hle einen Monat der angezeigt werden soll:");
define("_SHOWALLSTORIES","Zeige ALLE Stories");
define("_STORIESARCHIVE","Stories Archiv");
define("_ACTIONS","Aktionen");
define("_ARCHIVESINDEX","Stories Archiv Index");
define("_ALLSTORIESARCH","Alle Stories");
define("_NEXTPAGE","N&auml;chste Seite");
define("_PREVIOUSPAGE","Vorhergehende Seite");


?>
